@@ -2,4 +2,4 @@ import Test.Hspec
 import ShakespeareCssTest (specs)
 
 main :: IO ()
-main = hspecX $ descriptions [specs]
+main = hspecX [specs]
